{% load i18n %}
{% load static %}
{% load password_eye_extras %}

{% block extrahead %}
{% include_font_awesome "a" as include_font_awesome_library %}
{% if include_font_awesome_library %}
<link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" type="text/css" rel="stylesheet">
{% endif %}
<link rel="stylesheet" type="text/css" href="{% static 'django_password_eye/css/django_password_eye.css' %}?v=dpe.1.0.5" />
<script src="{% static 'django_password_eye/js/django_password_eye.js' %}?v=dpe.1.0.5"></script>
{% endblock %}

<div class="input-group django_password_eye" id="show_hide_password">
    <input type="password" name="{{ widget.name }}" maxlength=50 class="form-control"
           placeholder="{% trans 'Password' %}" data-toggle="password" style="position: relative"
           {% include "django/forms/widgets/attrs.html" %}
    >
    <div class="input-group-addon form-control link">
        <a><i class="fa fa-eye-slash" aria-hidden="true"></i></a>
    </div>
</div>